==> flutter_simple_template_bloc-0.0.6.tar.gz: lib/widgets/base_stateful_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_simple_template_bloc/flutter_simple_template_bloc.dart';

abstract class BaseStatefulWidget<C extends BlocBase<State>, State1>
    extends StatefulWidget {
  const BaseStatefulWidget({super.key});

  @override
  State<BaseStatefulWidget<C, State1>> createState() =>
      _BaseStatefulWidgetState();

  /// afterFirstLayout: This method will be triggerd when UI finished rendered at first time
  void afterFirstLayout(BuildContext context) {}

  /// Used for setting before returning the first build
  void init(BuildContext context) async {}

  void dispose();

  void listener(BuildContext context, State state);

  /// Get size of the device
  Size getSize(BuildContext context) => MediaQuery.of(context).size;

  /// Get the theme of the device
  TextTheme getTextTheme(BuildContext context) => Theme.of(context).textTheme;

  /// Provider UI builder based on state change
  Widget builder(BuildContext context, State state);

  // Show snack bar
  void showSnackbar() {}

  // Show dialog
  void showDialogMessage() {}

  // Hide keyboard
  void removeKeyBoard() {
    FocusManager.instance.primaryFocus?.unfocus();
  }
}

class _BaseStatefulWidgetState<C extends BlocBase<State>, State1>
    extends State<BaseStatefulWidget<C, State1>> {
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance
        .addPostFrameCallback((_) => widget.afterFirstLayout(context));
    widget.init(context);
  }

  @override
  void dispose() {
    widget.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return BlocListener<C, State>(
      listener: widget.listener,
      child: BlocBuilder<C, State>(
        builder: widget.builder,
      ),
    );
  }
}

==> flutter_simple_template_bloc-0.0.8.tar.gz: lib/widgets/base_stateful_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_simple_template_bloc/flutter_simple_template_bloc.dart';

abstract class BaseStatefulWidget<C extends BlocBase<StateBloc>, StateBloc>
    extends StatefulWidget {
  const BaseStatefulWidget({super.key});

  @override
  State<BaseStatefulWidget<C, StateBloc>> createState() =>
      _BaseStatefulWidgetState();

  /// afterFirstLayout: This method will be triggerd when UI finished rendered at first time
  void afterFirstLayout(BuildContext context) {}

  /// Used for setting before returning the first build
  void init(BuildContext context) async {}

  void dispose();

  void listener(BuildContext context, StateBloc state);

  /// Get size of the device
  Size getSize(BuildContext context) => MediaQuery.of(context).size;

  /// Get the theme of the device
  TextTheme getTextTheme(BuildContext context) => Theme.of(context).textTheme;

  /// Provider UI builder based on state change
  Widget builder(BuildContext context, StateBloc state);

  // Show snack bar
  void showSnackbar() {}

  // Show dialog
  void showDialogMessage() {}

  // Hide keyboard
  void removeKeyBoard() {
    FocusManager.instance.primaryFocus?.unfocus();
  }
}

class _BaseStatefulWidgetState<C extends BlocBase<StateBloc>, StateBloc>
    extends State<BaseStatefulWidget<C, StateBloc>> {
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance
        .addPostFrameCallback((_) => widget.afterFirstLayout(context));
    widget.init(context);
  }

  @override
  void dispose() {
    widget.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return BlocListener<C, StateBloc>(
      listener: widget.listener,
      child: BlocBuilder<C, StateBloc>(
        builder: widget.builder,
      ),
    );
  }
}
